@@ -1,4 +1,5 @@
 import sys
+
 from modulegraph.modulegraph import MissingModule
 
 
@@ -8,8 +9,8 @@ def check(cmd, mf):
 
     # Optional dependency on XML+ package in the stdlib, ignore
     # this when the package isn't present.
-    m = mf.findNode('_xmlplus')
+    m = mf.findNode("_xmlplus")
     if m is not None and isinstance(m, MissingModule):
-        mf.removeReference(mf.findNode('xml'), m)
+        mf.removeReference(mf.findNode("xml"), m)
 
     return {}
